===================================
``psyclone.psyir.nodes.assignment``
===================================

.. automodule:: psyclone.psyir.nodes.assignment

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.assignment
